<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Жизнь вне браузера!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Версия %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Зарегистрирована на: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 - свободное ПО, но его разработка отнимает драгоценное время.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Пожалуйста, &lt;a href=&apos;%1&apos;&gt;поддержите&lt;/a&gt; дальнейшую разработку %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Перевести %1 на ваш родной язык с помощью %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Автор значка %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Выпущено на условиях &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Введите ваши детали лицензии</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Код:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>	
Лицензия %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Демонстрационный период истек.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Полная версия позволит смотреть видео без пауз.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Срок работы, этого приложения, без лицензии истекает через %1 дн.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>При покупке полной версии, вы также оказываете поддержку тяжелой работы в создании %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Использовать демо версию</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Ввести лицензию</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Купить лицензию</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Загрузить</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>От %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Все видео</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Не просмотренное видео</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Недавно обновленные</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Недавно добавленные</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Недавно просмотренные</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Наиболее просматриваемые</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Сортировать по</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Отметить все как просмотренное</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Показать обновленные</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>У вас нет подписок. Используйте символ звездочки чтобы подписаться на каналы.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Все видео</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Не просмотренное видео</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Отметить как Просмотренное.</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Отписаться</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>В настоящее время нет обновлений подписок.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Только что</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 просмотров</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>байт</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>Кбайт</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>Мбайт</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>байт/сек</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>Кбайт/сек</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>Мбайт/сек</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>секунд</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>минут</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>осталось %4 %5</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 загружен в %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Загрузка завершена</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Изменить путь...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Выбрать путь загрузки</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Путь для загружаемых файлов изменён.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Файлы, загружаемые в данный момент будут сохранены по прежнему адресу.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Файлы загружаются в %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Загрузки</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Исполняемый файл был изменен, возможно вирусом.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 не запущено. Попробуйте установить ещё раз.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Переустановить</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Воспроизведение</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Воспр./Пауза</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Стоп после этого клипа</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>След. клип</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Пред. клип</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Громче</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Тише</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Заглушить</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Перемотать вперед</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Перемотать назад</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Поиск видео и каналов по запросу</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Смотреть</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Смотреть видео по категориям</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Подписки</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Подписки на каналы</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Чувствуйте себя как дома</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Окно</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Свернуть</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Остановить</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Остановить воспроизведение и вернуться к поиску</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>Пр&amp;едыдущий</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Вернуться к предыдущему треку</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>П&amp;ропустить</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Перейти к следующему клипу</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Пр&amp;оиграть</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Продолжить воспроизведение</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;На весь экран</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Полноэкранное воспроизведение</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>Компак&amp;тный режим</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Скрыть список воспроизведения и панель инструментов</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>От&amp;крыть страницу YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Приостановить воспроизведение и перейти на страницу видео в YouTube</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Копировать &amp;ссылку на YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Скопировать ссылку текущего клипа YouTube в буфер обмена</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Копировать ссылку на в&amp;идео поток</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Скопировать адрес текущего видео потока в буфер обмена</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Найти &amp;фрагменты видео</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Найти другие части видео, надеюсь, в правильном порядке</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Удалить выбранные клипы из списка воспроизведения</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>В&amp;верх</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Переместить выбранные видеоклипы вверх в списке воспроизведения</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>В&amp;низ</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Переместить выбранные видеоклипы вниз в списке воспроизведения</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>О&amp;чистить последние поисковые запросы</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Очистить историю запросов. Изменения необратимы.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Пока</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Домашняя страница</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 в интернете</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Сд&amp;елать пожертвование</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Поддержите дальнейшую разработку %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Сведения о %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Начать проигрывание вручную</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Начать проигрывание видео вручную</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>Загрузки</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Показать подробности о загрузках видео</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>Загрузить</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Загрузить проигрываемый файл</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Сделать скриншот</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>Подписаться на канал</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Поделиться текущим видео с помощью %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Email</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Поверх всех окон</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>Ост&amp;ановить после этого видео</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>Соо&amp;бщить об ошибке</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Уточнить поиск...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Больше...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>По&amp;хожее видео</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Смотреть видео, связанные с текущим</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Открыть в &amp;браузере...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Безопасный режим</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Скрыть видео, содержащие недопустимый контент </translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Нравится %1? Оцени!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Купить %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>Пр&amp;иложение</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Воспроизведение</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Список воспроизведения</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Видео</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Поделиться</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Просмотр</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Спр&amp;авка</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Нажмите %1 для увеличения громкости и %2 для уменьшения</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Выберите ваше расположение</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Открытие %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Вы действительно хотите закрыть %1 в то время, как загружаются файлы?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Если вы закроете %1 прямо сейчас, текущие загрузки будут отменены.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Выйти отменив загрузки</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Подождать завершения загрузок</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Ошибка: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Пауза</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Приостановить воспроизведение</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Загрузка...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Покинуть п&amp;олноэкранный режим</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Осталось: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Громкость %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Звук выключен</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Звук включен</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Максимальное разрешение видео: %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Конфиденциальность обеспечена</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Загрузка завершена</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 версия %2 теперь доступна.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Напомнить позже</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновление</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Теперь можно вставить адрес YouTube в другое приложение</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Теперь можно вставить адрес видео потока в другое приложение</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Адрес будет существовать ограниченное время.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Загружаю %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>из</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>часть</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>эпизод</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Отправить из %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Отписаться от %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Подписаться на %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Отписаны от %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Подписаны на %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Новая версия приложения %1 уже доступна!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 уже доступна. У вас %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Хотите загрузить сейчас?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Пропустить эту версию</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Напомнить позже</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Установить обновление</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 из %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Подготовка</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Завершено</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Остановлено</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Отмена загрузки</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Показать в %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Открыть родительский каталог</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Перезапустить загрузку</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Показать ещё %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Нет видео</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Нет больше видео</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Сортировать по</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Релевантность</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Кол-во просмотров</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Рейтинг</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>В любое время</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Сегодня</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 дней</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 дней</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Продолжительность</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Короткие</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Средние</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Длинные</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Короче чем 4 минуты</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Между 4 и 20 минутами</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Дольше чем 20 минут</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Качество</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Высокое разрешение</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p или больше</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Добро пожаловать в &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>чтобы начать просмотр.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>запрос</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Введите</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Последние запросы</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Последние каналы</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Купить полную версию</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>Н&amp;азад</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Вперед к %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Назад к %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Уточнить поиск</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Возможно вы имели в виду: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Изменить путь...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Скриншот сохранён в %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Директория для скриншотов изменена</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Самые популярные</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Загрузка обновления....</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Загрузка %1...</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Алжир</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Аргентина</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Австралия</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Бельгия</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Бразилия</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Канада</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Чили</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Колумбия</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Чехия</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Египет</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Франция</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Германия</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Гана</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Греция</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Гонконг</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Венгрия</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Индия</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Индонезия</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Ирландия</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Израиль</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Италия</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Япония</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Иордания</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Кения</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Малайзия</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Мексика</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Марокко</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Нидерланды</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Новая Зеландия</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Нигерия</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Перу</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Филиппины</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Польша</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Россия</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Саудовская Аравия</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Сингапур</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Южно-Африканская Республика</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Республика Корея</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Испания</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Швеция</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Тайвань</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Тунис</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Турция</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Уганда</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Объединённые Арабские Эмираты</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Великобритания</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Йемен</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Во всем мире</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Не удалось получить видео поток для %1</translation>
    </message>
</context>
</TS>